## Final Answer

We are finished our work on the following question:

```text
{question}
```

Consider the previous messages; did we come to a final answer through the team conversation? 

- If so, respond with that final answer.
- If not, THAT'S OK, let the user know that the results are incomplete, and summarize why we weren't able to come to a final answer.

### CRITICALLY IMPORTANT NOTES

- It's very important that you do not try to solve things yourself at the end. 
- If your team hasn't solved the problem, then it should be marked as "incomplete", even if you think you know the answer.
